@@ -59,9 +59,6 @@ static void add_bench_point(bbdo::pb_bench& event,
 
 uint32_t muxer::_event_queue_max_size = std::numeric_limits<uint32_t>::max();
 
-absl::Mutex muxer::_running_muxers_m;
-absl::flat_hash_map<std::string, std::weak_ptr<muxer>> muxer::_running_muxers;
-
 /**
  * @brief Constructor.
  *
@@ -168,12 +165,7 @@ std::shared_ptr<muxer> muxer::create(std::string name,
                                      bool persistent) {
   std::shared_ptr<muxer> retval;
   {
-    absl::MutexLock lck(&_running_muxers_m);
-    absl::erase_if(_running_muxers,
-                   [](const std::pair<std::string, std::weak_ptr<muxer>>& p) {
-                     return p.second.expired();
-                   });
-    retval = _running_muxers[name].lock();
+    retval = parent->get_muxer(name);
     if (retval) {
       log_v2::instance()
           .get(log_v2::CONFIG)
@@ -192,7 +184,7 @@ std::shared_ptr<muxer> muxer::create(std::string name,
           ->debug("muxer: muxer '{}' unknown, creating it", name);
       retval = std::shared_ptr<muxer>(
           new muxer(name, parent, r_filter, w_filter, persistent));
-      _running_muxers[name] = retval;
+      parent->set_muxer(name, retval);
     }
   }
 
@@ -315,30 +307,32 @@ void muxer::_execute_reader_if_needed() {
       _logger, "muxer '{}' execute reader if needed data_handler", _name);
   bool expected = false;
   if (_reader_running.compare_exchange_strong(expected, true)) {
-    com::centreon::common::pool::io_context_ptr()->post(
-        [me = shared_from_this(), this] {
-          std::shared_ptr<data_handler> to_call;
-          {
-            absl::MutexLock lck(&_events_m);
-            to_call = _data_handler;
-          }
-          if (to_call) {
-            std::vector<std::shared_ptr<io::data>> to_fill;
-            to_fill.reserve(_events_size);
-            bool still_events_to_read = read(to_fill, _events_size);
-            uint32_t written = to_call->on_events(to_fill);
-            if (written > 0)
-              ack_events(written);
-            if (written != to_fill.size()) {
-              SPDLOG_LOGGER_ERROR(
-                  _logger,
-                  "Unable to handle all the incoming events in muxer '{}'",
-                  _name);
-              clear_action_on_new_data();
-            }
-            _reader_running.store(false);
-          }
-        });
+    asio::post(*com::centreon::common::pool::io_context_ptr(),
+               [me = shared_from_this(), this] {
+                 std::shared_ptr<data_handler> to_call;
+                 {
+                   absl::MutexLock lck(&_events_m);
+                   to_call = _data_handler;
+                 }
+                 if (to_call) {
+                   std::vector<std::shared_ptr<io::data>> to_fill;
+                   to_fill.reserve(_events_size);
+                   bool still_events_to_read [[maybe_unused]] =
+                       read(to_fill, _events_size);
+                   uint32_t written = to_call->on_events(to_fill);
+                   if (written > 0)
+                     ack_events(written);
+                   if (written != to_fill.size()) {
+                     SPDLOG_LOGGER_ERROR(
+                         _logger,
+                         "Unable to handle all the incoming events in "
+                         "muxer '{}'",
+                         _name);
+                     clear_action_on_new_data();
+                   }
+                   _reader_running.store(false);
+                 }
+               });
   }
 }
 
