@@ -41,7 +41,8 @@ using log_v2 = com::centreon::common::log_v2::log_v2;
  *  is running. We will be able to add this endpoint later, following the flag
  *  value.
  */
-bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
+bool factory::has_endpoint(const config::endpoint& cfg,
+                           io::extension* ext) const {
   if (ext) {
     if (direct_grpc_serialized(cfg)) {
       return false;
@@ -49,7 +50,7 @@ bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
     if (cfg.type == "bbdo_server" || cfg.type == "bbdo_client") {
       auto it = cfg.params.find("transport_protocol");
       if (it != cfg.params.end()) {
-        if (absl::EqualsIgnoreCase(cfg.params["transport_protocol"], "grpc")) {
+        if (absl::EqualsIgnoreCase(it->second, "grpc")) {
           *ext = io::extension("COMPRESSION", false, false);
           return false;
         }
