@@ -149,10 +149,11 @@ absl::optional<std::string> parser::check_and_read<std::string>(
  *  Parse a configuration file.
  *
  *  @param[in]  file File to process.
+ *  @param[in]  neb_module true if we are in case of neb module
  *
  *  @return a state corresponding to the json file processed.
  */
-state parser::parse(std::string const& file) {
+state parser::parse(std::string const& file, bool neb_module) {
   state retval;
   // Parse JSON document.
   std::ifstream f(file);
@@ -357,54 +358,62 @@ state parser::parse(std::string const& file) {
             throw msg_fmt("the log configuration should be a json object");
 
           auto& conf = retval.mut_log_conf();
-          if (conf_js.contains("directory") && conf_js["directory"].is_string())
-            conf.set_dirname(conf_js["directory"].get<std::string>());
-          else if (conf_js.contains("directory") &&
-                   !conf_js["directory"].is_null())
-            throw msg_fmt(
-                "'directory' key in the log configuration must contain a "
-                "directory name");
-          if (conf.dirname().empty())
-            conf.set_dirname("/var/log/centreon-broker");
-
-          if (!misc::filesystem::writable(conf.dirname()))
-            throw msg_fmt("The log directory '{}' is not writable",
-                          conf.dirname());
-
-          conf.set_filename("");
-
-          if (conf_js.contains("filename") && conf_js["filename"].is_string()) {
-            conf.set_filename(conf_js["filename"].get<std::string>());
-            if (conf.filename().find("/") != std::string::npos)
+          // In case of neb used by centengine, many logs parameters are yet set
+          // by engine configuration
+          if (!neb_module) {
+            if (conf_js.contains("directory") &&
+                conf_js["directory"].is_string())
+              conf.set_dirname(conf_js["directory"].get<std::string>());
+            else if (conf_js.contains("directory") &&
+                     !conf_js["directory"].is_null())
               throw msg_fmt(
-                  "'filename' must only contain a filename without directory");
+                  "'directory' key in the log configuration must contain a "
+                  "directory name");
+            if (conf.dirname().empty())
+              conf.set_dirname("/var/log/centreon-broker");
 
-          } else if (conf_js.contains("filename") &&
-                     !conf_js["filename"].is_null())
-            throw msg_fmt(
-                "'filename' key in the log configuration must contain the log "
-                "file name");
+            if (!misc::filesystem::writable(conf.dirname()))
+              throw msg_fmt("The log directory '{}' is not writable",
+                            conf.dirname());
 
-          auto ms = check_and_read<int64_t>(conf_js, "max_size");
-          conf.set_max_size(ms ? ms.value() : 0u);
+            conf.set_filename("");
 
-          auto fp = check_and_read<int64_t>(conf_js, "flush_period");
-          if (fp) {
-            if (fp.value() < 0)
+            if (conf_js.contains("filename") &&
+                conf_js["filename"].is_string()) {
+              conf.set_filename(conf_js["filename"].get<std::string>());
+              if (conf.filename().find("/") != std::string::npos)
+                throw msg_fmt(
+                    "'filename' must only contain a filename without "
+                    "directory");
+
+            } else if (conf_js.contains("filename") &&
+                       !conf_js["filename"].is_null())
               throw msg_fmt(
-                  "'flush_period' key in the log configuration must contain a "
-                  "positive number or 0.");
+                  "'filename' key in the log configuration must contain the "
+                  "log "
+                  "file name");
 
-            conf.set_flush_interval(fp.value());
-          } else
-            conf.set_flush_interval(0u);
+            auto ms = check_and_read<int64_t>(conf_js, "max_size");
+            conf.set_max_size(ms ? ms.value() : 0u);
 
-          auto lp = check_and_read<bool>(conf_js, "log_pid");
-          conf.set_log_pid(lp ? lp.value() : false);
+            auto fp = check_and_read<int64_t>(conf_js, "flush_period");
+            if (fp) {
+              if (fp.value() < 0)
+                throw msg_fmt(
+                    "'flush_period' key in the log configuration must contain "
+                    "a "
+                    "positive number or 0.");
 
-          auto ls = check_and_read<bool>(conf_js, "log_source");
-          conf.set_log_source(ls ? ls.value() : false);
+              conf.set_flush_interval(fp.value());
+            } else
+              conf.set_flush_interval(0u);
 
+            auto lp = check_and_read<bool>(conf_js, "log_pid");
+            conf.set_log_pid(lp ? lp.value() : false);
+
+            auto ls = check_and_read<bool>(conf_js, "log_source");
+            conf.set_log_source(ls ? ls.value() : false);
+          }
           if (conf_js.contains("loggers") && conf_js["loggers"].is_object()) {
             conf.loggers().clear();
             for (auto it = conf_js["loggers"].begin();
