@@ -18,10 +18,6 @@
 
 #include "com/centreon/broker/persistent_cache.hh"
 
-#include <unistd.h>
-
-#include <cerrno>
-
 #include "com/centreon/broker/bbdo/stream.hh"
 #include "com/centreon/broker/exceptions/shutdown.hh"
 #include "com/centreon/broker/file/opener.hh"
