@@ -66,9 +66,8 @@ bool broker_module_deinit() {
  *
  *  @param[in] arg Configuration object.
  */
-void broker_module_init(void const* arg) {
-  (void)arg;
-  auto logger = log_v2::instance().get(log_v2::NEB);
+void broker_module_init(void const* arg [[maybe_unused]]) {
+  auto logger = log_v2::instance().get(log_v2::CONFIG);
   if (!neb_instances++) {
     logger->info("NEB: module for Centreon Broker {}", CENTREON_BROKER_VERSION);
     io::events& e(io::events::instance());
@@ -94,10 +93,6 @@ void broker_module_init(void const* arg) {
       e.register_event(make_type(io::neb, neb::de_host_check), "host_check",
                        &neb::host_check::operations, neb::host_check::entries,
                        "hosts");
-      e.register_event(make_type(io::neb, neb::de_host_dependency),
-                       "host_dependency", &neb::host_dependency::operations,
-                       neb::host_dependency::entries,
-                       "hosts_hosts_dependencies");
       e.register_event(make_type(io::neb, neb::de_host), "host",
                        &neb::host::operations, neb::host::entries, "hosts");
       e.register_event(make_type(io::neb, neb::de_host_group), "host_group",
@@ -124,10 +119,6 @@ void broker_module_init(void const* arg) {
       e.register_event(make_type(io::neb, neb::de_service_check),
                        "service_check", &neb::service_check::operations,
                        neb::service_check::entries, "services");
-      e.register_event(
-          make_type(io::neb, neb::de_service_dependency), "service_dependency",
-          &neb::service_dependency::operations,
-          neb::service_dependency::entries, "services_services_dependencies");
       e.register_event(make_type(io::neb, neb::de_service), "service",
                        &neb::service::operations, neb::service::entries,
                        "services");
@@ -175,8 +166,7 @@ void broker_module_init(void const* arg) {
                        &neb::pb_host_status::operations, "hosts");
       e.register_event(make_type(io::neb, neb::de_pb_adaptive_host_status),
                        "AdaptiveHostStatus",
-                       &neb::pb_adaptive_host_status::operations,
-                       "hosts");
+                       &neb::pb_adaptive_host_status::operations, "hosts");
 
       e.register_event(make_type(io::neb, neb::de_pb_severity), "Severity",
                        &neb::pb_severity::operations, "severities");
@@ -219,13 +209,6 @@ void broker_module_init(void const* arg) {
       e.register_event(make_type(io::neb, neb::de_pb_acknowledgement),
                        "Acknowledgement", &neb::pb_acknowledgement::operations,
                        "acknowledgements");
-      e.register_event(neb::pb_host_dependency::static_type(), "HostDependency",
-                       &neb::pb_host_dependency::operations,
-                       "hosts_hosts_dependencies");
-      e.register_event(neb::pb_service_dependency::static_type(),
-                       "ServiceDependency",
-                       &neb::pb_service_dependency::operations,
-                       "services_services_dependencies");
       e.register_event(neb::pb_host_group::static_type(), "HostGroup",
                        &neb::pb_host_group::operations, "hostgroups");
       e.register_event(
@@ -243,6 +226,8 @@ void broker_module_init(void const* arg) {
                        &neb::pb_instance_configuration::operations, "no_table");
       e.register_event(neb::pb_otl_metrics::static_type(), "OTLMetrics",
                        &neb::pb_otl_metrics::operations, "otl_metrics");
+      e.register_event(neb::pb_agent_stats::static_type(), "AgentStats",
+                       &neb::pb_agent_stats::operations, "agent_information");
     }
   }
 }
