@@ -35,11 +35,11 @@ using com::centreon::common::log_v2::log_v2;
  *
  *  @return True if the endpoint match the configuration.
  */
-bool factory::has_endpoint(config::endpoint& cfg, io::extension* ext) {
+bool factory::has_endpoint(const config::endpoint& cfg,
+                           io::extension* ext) const {
   if (ext)
     *ext = io::extension("SQL", false, false);
-  bool is_sql{absl::EqualsIgnoreCase(cfg.type, "sql")};
-  return is_sql;
+  return absl::EqualsIgnoreCase(cfg.type, "sql");
 }
 
 /**
