@@ -17,11 +17,17 @@
  */
 
 #include "com/centreon/engine/configuration/extended_conf.hh"
-#include "com/centreon/engine/configuration/state.hh"
-#include "com/centreon/engine/globals.hh"
+#include <google/protobuf/util/json_util.h>
 #include "com/centreon/exceptions/msg_fmt.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/state.hh"
+#else
+#include "common/engine_conf/state_helper.hh"
+#endif
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::engine::configuration;
+using com::centreon::common::log_v2::log_v2;
 
 std::list<std::unique_ptr<extended_conf>> extended_conf::_confs;
 
@@ -31,17 +37,18 @@ std::list<std::unique_ptr<extended_conf>> extended_conf::_confs;
  * @param path of the configuration file
  * @throw exception if json malformed
  */
-extended_conf::extended_conf(const std::string& path) : _path(path) {
+extended_conf::extended_conf(const std::string& path)
+    : _logger{log_v2::instance().get(log_v2::CONFIG)}, _path(path) {
   if (::stat(_path.c_str(), &_file_info)) {
-    SPDLOG_LOGGER_ERROR(config_logger, "can't access to {}", _path);
+    SPDLOG_LOGGER_ERROR(_logger, "can't access to {}", _path);
     throw exceptions::msg_fmt("can't access to {}", _path);
   }
   try {
     _content = common::rapidjson_helper::read_from_file(_path);
-    SPDLOG_LOGGER_INFO(config_logger, "extended conf file {} loaded", _path);
+    SPDLOG_LOGGER_INFO(_logger, "extended conf file {} loaded", _path);
   } catch (const std::exception& e) {
     SPDLOG_LOGGER_ERROR(
-        config_logger,
+        _logger,
         "extended_conf::extended_conf : fail to read json content from {}: {}",
         _path, e.what());
     throw;
@@ -57,9 +64,8 @@ extended_conf::extended_conf(const std::string& path) : _path(path) {
 void extended_conf::reload() {
   struct stat file_info;
   if (::stat(_path.c_str(), &file_info)) {
-    SPDLOG_LOGGER_ERROR(config_logger,
-                        "can't access to {} anymore => we keep old content",
-                        _path);
+    SPDLOG_LOGGER_ERROR(
+        _logger, "can't access to {} anymore => we keep old content", _path);
     return;
   }
   if (!memcmp(&file_info, &_file_info, sizeof(struct stat))) {
@@ -69,13 +75,14 @@ void extended_conf::reload() {
     _content = common::rapidjson_helper::read_from_file(_path);
     _file_info = file_info;
   } catch (const std::exception& e) {
-    SPDLOG_LOGGER_ERROR(config_logger,
+    SPDLOG_LOGGER_ERROR(_logger,
                         "extended_conf::extended_conf : fail to read json "
                         "content from {} => we keep old content, cause: {}",
                         _path, e.what());
   }
 }
 
+#ifdef LEGACY_CONF
 /**
  * @brief reload all optional configuration files if needed
  * Then these configuration content are applied to dest
@@ -88,3 +95,37 @@ void extended_conf::update_state(state& dest) {
     dest.apply_extended_conf(conf_file->_path, conf_file->_content);
   }
 }
+#else
+/**
+ * @brief reload all optional configuration files if needed
+ * Then these configuration content are applied to dest
+ *
+ * @param dest
+ */
+void extended_conf::update_state(State* pb_config) {
+  for (auto& conf_file : _confs) {
+    conf_file->reload();
+    std::ifstream f(conf_file->_path, std::ios::in);
+    std::string content;
+    if (f) {
+      f.seekg(0, std::ios::end);
+      content.resize(f.tellg());
+      f.seekg(0, std::ios::beg);
+      f.read(&content[0], content.size());
+      f.close();
+      State new_conf;
+      google::protobuf::util::JsonParseOptions options;
+      options.ignore_unknown_fields = false;
+      options.case_insensitive_enum_parsing = true;
+      auto status [[maybe_unused]] =
+          google::protobuf::util::JsonStringToMessage(content, &new_conf);
+      pb_config->MergeFrom(new_conf);
+    } else {
+      SPDLOG_LOGGER_ERROR(
+          conf_file->_logger,
+          "extended_conf::extended_conf : fail to read json content '{}': {}",
+          conf_file->_path, strerror(errno));
+    }
+  }
+}
+#endif
