@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2023 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,7 +16,6 @@
  * For more information : contact@centreon.com
  *
  */
-
 #define C4_NO_DEBUG_BREAK 1
 
 #include "com/centreon/engine/configuration/whitelist.hh"
@@ -30,13 +29,14 @@
 #include <ryml/ryml.hpp>
 
 #include "absl/base/call_once.h"
-#include "com/centreon/engine/globals.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon;
 using namespace com::centreon::exceptions;
 using namespace com::centreon::engine;
 using namespace com::centreon::engine::configuration;
+using com::centreon::common::log_v2::log_v2;
 
 namespace com::centreon::engine::configuration {
 
@@ -52,7 +52,7 @@ const std::string command_blacklist_output(
  * by default on error rapidyaml call abort so this handler
  */
 void on_rapidyaml_error(const char* buff,
-                        size_t length,
+                        size_t length [[maybe_unused]],
                         ryml::Location loc,
                         void*) {
   throw msg_fmt("fail to parse {} at line {}: {}", loc.name.data(), loc.line,
@@ -75,7 +75,7 @@ void whitelist::init_ryml_error_handler() {
   });
 }
 
-static std::atomic_uint _instance_gen(1);
+std::atomic_uint whitelist::_instance_gen(1);
 
 /**
  * @brief Construct a new whitelist::whitelist object
@@ -84,7 +84,8 @@ static std::atomic_uint _instance_gen(1);
  * @param file_path
  */
 whitelist::whitelist(const std::string_view& file_path)
-    : _instance_id(_instance_gen.fetch_add(1)) {
+    : _logger{log_v2::instance().get(log_v2::CONFIG)},
+      _instance_id(_instance_gen.fetch_add(1)) {
   init_ryml_error_handler();
   _parse_file(file_path);
 }
@@ -98,15 +99,15 @@ bool whitelist::_parse_file(const std::string_view& file_path) {
   // check file
   struct stat infos;
   if (::stat(file_path.data(), &infos)) {
-    SPDLOG_LOGGER_ERROR(config_logger, "{} doesn't exist", file_path);
+    SPDLOG_LOGGER_ERROR(_logger, "{} doesn't exist", file_path);
     return false;
   }
   if ((infos.st_mode & S_IFMT) != S_IFREG) {
-    SPDLOG_LOGGER_ERROR(config_logger, "{} is not a regular file", file_path);
+    SPDLOG_LOGGER_ERROR(_logger, "{} is not a regular file", file_path);
     return false;
   }
   if (!infos.st_size) {
-    SPDLOG_LOGGER_ERROR(config_logger, "{} is an empty file", file_path);
+    SPDLOG_LOGGER_ERROR(_logger, "{} is an empty file", file_path);
     return false;
   }
 
@@ -114,13 +115,12 @@ bool whitelist::_parse_file(const std::string_view& file_path) {
 
   if (centengine_group) {
     if (infos.st_uid || infos.st_gid != centengine_group->gr_gid) {
-      SPDLOG_LOGGER_ERROR(config_logger,
-                          "file {} must be owned by root@centreon-engine",
-                          file_path);
+      SPDLOG_LOGGER_ERROR(
+          _logger, "file {} must be owned by root@centreon-engine", file_path);
     }
   }
   if (infos.st_mode & S_IRWXO || (infos.st_mode & S_IRWXG) != S_IRGRP) {
-    SPDLOG_LOGGER_ERROR(config_logger, "file {} must have x40 right access",
+    SPDLOG_LOGGER_ERROR(_logger, "file {} must have x40 right access",
                         file_path);
   }
 
@@ -134,14 +134,13 @@ bool whitelist::_parse_file(const std::string_view& file_path) {
       std::streamsize some_read =
           f.readsome(buff.get() + read, file_size - read);
       if (some_read <= 0) {
-        SPDLOG_LOGGER_ERROR(config_logger, "fail to read {}", file_path);
+        SPDLOG_LOGGER_ERROR(_logger, "fail to read {}", file_path);
         return false;
       }
       read += some_read;
     }
   } catch (const std::exception& e) {
-    SPDLOG_LOGGER_ERROR(config_logger, "fail to read {}: {}", file_path,
-                        e.what());
+    SPDLOG_LOGGER_ERROR(_logger, "fail to read {}: {}", file_path, e.what());
     return false;
   }
   // parse file content
@@ -150,8 +149,7 @@ bool whitelist::_parse_file(const std::string_view& file_path) {
     ryml::Tree tree = ryml::parse_in_place(ryml::substr(buff.get(), file_size));
     return _read_file_content(tree);
   } catch (const std::exception& e) {
-    SPDLOG_LOGGER_ERROR(config_logger, "fail to parse {}: {}", file_path,
-                        e.what());
+    SPDLOG_LOGGER_ERROR(_logger, "fail to parse {}: {}", file_path, e.what());
     return false;
   }
 }
@@ -164,43 +162,87 @@ bool whitelist::_parse_file(const std::string_view& file_path) {
  */
 template <class ryml_tree>
 bool whitelist::_read_file_content(const ryml_tree& file_content) {
-  ryml::ConstNodeRef root = file_content["whitelist"];
-  ryml::ConstNodeRef wildcards = root.find_child("wildcard");
-  ryml::ConstNodeRef regexps = root.find_child("regex");
+  ryml::ConstNodeRef root = file_content;
+
   bool ret = false;
-  if (wildcards.valid() && !wildcards.empty()) {
-    if (!wildcards.is_seq()) {  // not an array => error
-      SPDLOG_LOGGER_ERROR(config_logger, "{}: wildcard is not a sequence");
-    } else {
-      for (auto wildcard : wildcards) {
-        auto value = wildcard.val();
-        std::string_view str_value(value.data(), value.size());
-        SPDLOG_LOGGER_INFO(config_logger, "wildcard '{}' added to whitelist",
-                           str_value);
-        _wildcards.emplace_back(str_value);
-        ret = true;
+
+  auto load_ruleset = [&](const ryml::ConstNodeRef& node, rule_set& rules) {
+    // add whildcard and regexps
+    if (node.has_child("wildcard")) {
+      auto wc_node = node["wildcard"];
+      if (wc_node.is_seq()) {
+        for (auto wildcard : wc_node) {
+          auto value = wildcard.val();
+          if (value.size() > 0) {
+            std::string_view str_value(value.data(), value.size());
+            SPDLOG_LOGGER_INFO(_logger, "wildcard '{}' added to whitelist",
+                               str_value);
+            rules.wildcard.emplace_back(str_value);
+            ret = true;
+          }
+        }
+      } else {
+        SPDLOG_LOGGER_ERROR(_logger, "wildcard is not a sequence");
       }
     }
+
+    if (node.has_child("regex")) {
+      auto re_node = node["regex"];
+      if (re_node.is_seq()) {
+        for (auto re : re_node) {
+          auto value = re.val();
+          if (value.size() > 0) {
+            std::string_view str_value(value.data(), value.size());
+            std::unique_ptr<re2::RE2> to_push_back =
+                std::make_unique<re2::RE2>(str_value);
+            if (to_push_back->error_code() == re2::RE2::ErrorCode::NoError) {
+              SPDLOG_LOGGER_INFO(_logger, "regexp '{}' added to whitelist",
+                                 str_value);
+              rules.regex.push_back(std::move(to_push_back));
+              ret = true;
+            } else {
+              SPDLOG_LOGGER_ERROR(_logger, "fail to parse {}: error: {} at {} ",
+                                  str_value, to_push_back->error(),
+                                  to_push_back->error_arg());
+            }
+          }
+        }
+      } else {
+        SPDLOG_LOGGER_ERROR(_logger, "regex is not a sequence");
+      }
+    }
+  };
+
+  /* 1. whitelist -----------------------------------------------------------*/
+  if (root.has_child("whitelist")) {
+    ryml::ConstNodeRef whitelist = root["whitelist"];
+    load_ruleset(whitelist, _config.engine);
   }
-  if (regexps.valid() && !regexps.empty()) {
-    if (!regexps.is_seq()) {  // not an array => error
-      SPDLOG_LOGGER_ERROR(config_logger, "{}: regex is not a sequence");
-    } else {
-      for (auto re : regexps) {
-        auto value = re.val();
-        std::string_view str_value(value.data(), value.size());
-        std::unique_ptr<re2::RE2> to_push_back =
-            std::make_unique<re2::RE2>(str_value);
-        if (to_push_back->error_code() ==
-            re2::RE2::ErrorCode::NoError) {  // success compile regex
-          SPDLOG_LOGGER_INFO(config_logger, "regexp '{}' added to whitelist",
-                             str_value);
-          _regex.push_back(std::move(to_push_back));
+
+  /* 2. cma-whitelist (optional) ------------------------------------------- */
+  if (root.has_child("cma-whitelist")) {
+    ryml::ConstNodeRef cma = root["cma-whitelist"];
+
+    /* default ----------------------------------------------------------- */
+    if (cma.has_child("default")) {
+      auto seq = cma["default"];
+      load_ruleset(seq, _config.cma.defaults);
+    }
+
+    /* hosts ------------------------------------------------------------- */
+    if (cma.has_child("hosts")) {
+      ryml::ConstNodeRef hosts = cma["hosts"];
+      for (const ryml::ConstNodeRef& host : hosts) {
+        auto hostname = host["hostname"].val();
+        if (hostname.size() > 0) {
+          std::string_view str_hostname(hostname.data(), hostname.size());
+          SPDLOG_LOGGER_INFO(_logger, "cma whitelist for host '{}'",
+                             str_hostname);
+          rule_set& rules = _config.cma.hosts[std::string(str_hostname)];
+          load_ruleset(host, rules);
           ret = true;
-        } else {  // bad regex
-          SPDLOG_LOGGER_ERROR(
-              config_logger, "fail to parse regex {}: error: {} at {} ",
-              str_value, to_push_back->error(), to_push_back->error_arg());
+        } else {
+          SPDLOG_LOGGER_ERROR(_logger, "cma whitelist host name is empty");
         }
       }
     }
@@ -209,25 +251,34 @@ bool whitelist::_read_file_content(const ryml_tree& file_content) {
 }
 
 /**
- * @brief test if a cmdline matches
+ * @brief Determines if a command is permitted according to configured wildcard
+ * and regex rules.
  *
- * @param cmdline
- * @return true  cmdline matches to at least one regex or wildcard
- * @return false  cmdline don't match
+ * The cmdline is first normalized by collapsing any "//" sequences into a
+ * single "/". If the provided rule_set contains no wildcard or regex patterns,
+ * the command is always allowed. Otherwise, this function:
+ *   1. Applies each wildcard pattern (fnmatch with FNM_PATHNAME | FNM_PERIOD).
+ *   2. If no wildcard matches, applies each regex pattern (RE2::FullMatch).
+ * The command is allowed as soon as one pattern matches.
+ *
+ * @param cmdline Full command line (macros already expanded) to test.
+ * @param rules   Rule set containing wildcard and regex patterns.
+ * @return true  cmdline matches at least one wildcard or regex rule.
+ * @return false cmdline does not match any configured rule.
  */
-bool whitelist::is_allowed(const std::string& cmdline) {
-  if (_wildcards.empty() && _regex.empty()) {
+bool whitelist::_is_allowed(const std::string& cmdline, const rule_set& rules) {
+  if (rules.wildcard.empty() && rules.regex.empty()) {
     return true;
   }
   auto check_cmd_line = [&](const std::string& clean_cmdline) -> bool {
-    for (const std::string& wildcard : _wildcards) {
+    for (const std::string& wildcard : rules.wildcard) {
       if (!fnmatch(wildcard.c_str(), clean_cmdline.c_str(),
                    FNM_PATHNAME | FNM_PERIOD)) {
         return true;
       }
     }
 
-    for (const auto& regex : _regex) {
+    for (const auto& regex : rules.regex) {
       if (RE2::FullMatch(clean_cmdline, *regex)) {
         return true;
       }
@@ -244,6 +295,29 @@ bool whitelist::is_allowed(const std::string& cmdline) {
   }
 }
 
+/**
+ * Check if a command is allowed by the CMA whitelist.
+ * Uses host-specific rules when available, otherwise falls back to defaults.
+ *
+ * @param cmdline Final command line (macros expanded)
+ * @param hostname Host name to check (empty = use default rules)
+ * @return true if the command is allowed, false otherwise
+ */
+bool whitelist::is_allowed_by_cma(const std::string& cmdline,
+                                  const std::string& hostname) {
+  const auto& defaults = _config.cma.defaults;
+  if (defaults.wildcard.empty() && defaults.regex.empty() &&
+      _config.cma.hosts.empty())
+    return true;
+
+  if (!hostname.empty()) {
+    auto it = _config.cma.hosts.find(hostname);
+    if (it != _config.cma.hosts.end())
+      return _is_allowed(cmdline, it->second);
+  }
+  return _is_allowed(cmdline, defaults);
+}
+
 /**
  * @brief parse all whitelist files in a directory
  *
@@ -258,7 +332,7 @@ whitelist::e_refresh_result whitelist::parse_dir(
     return e_refresh_result::no_directory;
   }
   if ((dir_infos.st_mode & S_IFMT) != S_IFDIR) {
-    SPDLOG_LOGGER_ERROR(config_logger, "{} is not a directory: {}", directory,
+    SPDLOG_LOGGER_ERROR(_logger, "{} is not a directory: {}", directory,
                         dir_infos.st_mode);
     return e_refresh_result::no_directory;
   }
@@ -267,7 +341,7 @@ whitelist::e_refresh_result whitelist::parse_dir(
 
   if (centengine_group) {
     if (dir_infos.st_uid || dir_infos.st_gid != centengine_group->gr_gid) {
-      SPDLOG_LOGGER_ERROR(config_logger,
+      SPDLOG_LOGGER_ERROR(_logger,
                           "directory {} must be owned by root@centreon-engine",
                           directory);
     }
@@ -275,8 +349,8 @@ whitelist::e_refresh_result whitelist::parse_dir(
 
   if (dir_infos.st_mode & S_IRWXO ||
       (dir_infos.st_mode & S_IRWXG) != S_IRGRP + S_IXGRP) {
-    SPDLOG_LOGGER_ERROR(config_logger,
-                        "directory {} must have 750 right access", directory);
+    SPDLOG_LOGGER_ERROR(_logger, "directory {} must have 750 right access",
+                        directory);
   }
 
   try {
@@ -295,7 +369,7 @@ whitelist::e_refresh_result whitelist::parse_dir(
     }
     return res;
   } catch (const std::exception& e) {
-    SPDLOG_LOGGER_ERROR(config_logger, "fail to read {} directory: {}", directory,
+    SPDLOG_LOGGER_ERROR(_logger, "fail to read {} directory: {}", directory,
                         e.what());
     return e_refresh_result::no_directory;
   }
