@@ -1,24 +1,24 @@
 /**
  * Copyright 2011-2024 Centreon
  *
- * This file is part of Centreon Engine.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Centreon Engine is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Centreon Engine is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
  *
- * You should have received a copy of the GNU General Public License
- * along with Centreon Engine. If not, see
- * <http://www.gnu.org/licenses/>.
  */
-
 #include "com/centreon/engine/hostdependency.hh"
 #include "com/centreon/engine/broker.hh"
+#include "com/centreon/engine/configuration/applier/hostdependency.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/globals.hh"
@@ -28,15 +28,16 @@
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
-using namespace com::centreon::engine::configuration::applier;
 using namespace com::centreon::engine::logging;
 using namespace com::centreon::engine::string;
 
 hostdependency_mmap hostdependency::hostdependencies;
 
 /**
- *  Create a host dependency definition.
+ *  Create a host dependency definition. The key is given by the
+ *  applier::configuration::hostdependency object from its attributes.
  *
+ *  @param[in] key                 key representing this hostdependency.
  *  @param[in] dependent_hostname  Dependant host name.
  *  @param[in] hostname            Host name.
  *  @param[in] dependency_type     Dependency type.
@@ -49,7 +50,8 @@ hostdependency_mmap hostdependency::hostdependencies;
  *
  *  @return New host dependency.
  */
-hostdependency::hostdependency(std::string const& dependent_hostname,
+hostdependency::hostdependency(size_t key,
+                               std::string const& dependent_hostname,
                                std::string const& hostname,
                                dependency::types dependency_type,
                                bool inherits_parent,
@@ -58,7 +60,8 @@ hostdependency::hostdependency(std::string const& dependent_hostname,
                                bool fail_on_unreachable,
                                bool fail_on_pending,
                                std::string const& dependency_period)
-    : dependency(dependent_hostname,
+    : dependency(key,
+                 dependent_hostname,
                  hostname,
                  dependency_type,
                  inherits_parent,
@@ -225,12 +228,11 @@ bool hostdependency::check_for_circular_hostdependency_path(
   return false;
 }
 
-void hostdependency::resolve(int& w, int& e) {
-  (void)w;
-  int errors{0};
+void hostdependency::resolve(uint32_t& w [[maybe_unused]], uint32_t& e) {
+  int errors = 0;
 
   // Find the dependent host.
-  host_map::const_iterator it{host::hosts.find(_dependent_hostname)};
+  host_map::const_iterator it = host::hosts.find(_dependent_hostname);
   if (it == host::hosts.end() || !it->second) {
     engine_logger(log_verification_error, basic)
         << "Error: Dependent host specified in host dependency for "
@@ -299,6 +301,7 @@ void hostdependency::resolve(int& w, int& e) {
   }
 }
 
+#ifdef LEGACY_CONF
 /**
  *  Find a service dependency from its key.
  *
@@ -309,45 +312,37 @@ void hostdependency::resolve(int& w, int& e) {
  */
 hostdependency_mmap::iterator hostdependency::hostdependencies_find(
     const com::centreon::engine::configuration::hostdependency& k) {
-  typedef hostdependency_mmap collection;
-  std::pair<collection::iterator, collection::iterator> p;
+  std::pair<hostdependency_mmap::iterator, hostdependency_mmap::iterator> p;
+
+  size_t key = configuration::hostdependency_key(k);
 
   p = hostdependencies.equal_range(*k.dependent_hosts().begin());
   while (p.first != p.second) {
-    configuration::hostdependency current;
-    current.configuration::object::operator=(k);
-    current.dependent_hosts().insert(p.first->second->get_dependent_hostname());
-    current.hosts().insert(p.first->second->get_hostname());
-    current.dependency_period(
-        (!p.first->second->get_dependency_period().empty()
-             ? p.first->second->get_dependency_period().c_str()
-             : ""));
-    current.inherits_parent(p.first->second->get_inherits_parent());
-    unsigned int options((p.first->second->get_fail_on_up()
-                              ? configuration::hostdependency::up
-                              : 0) |
-                         (p.first->second->get_fail_on_down()
-                              ? configuration::hostdependency::down
-                              : 0) |
-                         (p.first->second->get_fail_on_unreachable()
-                              ? configuration::hostdependency::unreachable
-                              : 0) |
-                         (p.first->second->get_fail_on_pending()
-                              ? configuration::hostdependency::pending
-                              : 0));
-    if (p.first->second->get_dependency_type() ==
-        engine::hostdependency::notification) {
-      current.dependency_type(
-          configuration::hostdependency::notification_dependency);
-      current.notification_failure_options(options);
-    } else {
-      current.dependency_type(
-          configuration::hostdependency::execution_dependency);
-      current.execution_failure_options(options);
-    }
-    if (current == k)
+    if (p.first->second->internal_key() == key)
       break;
     ++p.first;
   }
-  return (p.first == p.second) ? hostdependencies.end() : p.first;
+  return p.first == p.second ? hostdependencies.end() : p.first;
 }
+#else
+/**
+ *  Find a service dependency from its key.
+ *
+ *  @param[in] k The service dependency configuration.
+ *
+ *  @return Iterator to the element if found,
+ *          servicedependencies().end() otherwise.
+ */
+hostdependency_mmap::iterator hostdependency::hostdependencies_find(
+    const std::pair<std::string_view, size_t>& key) {
+  std::pair<hostdependency_mmap::iterator, hostdependency_mmap::iterator> p;
+
+  p = hostdependencies.equal_range(key.first);
+  while (p.first != p.second) {
+    if (p.first->second->internal_key() == key.second)
+      break;
+    ++p.first;
+  }
+  return p.first == p.second ? hostdependencies.end() : p.first;
+}
+#endif
