@@ -1,22 +1,20 @@
 /**
  * Copyright 2011-2024 Centreon
  *
- * This file is part of Centreon Engine.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Centreon Engine is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
- * Centreon Engine is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  *
- * You should have received a copy of the GNU General Public License
- * along with Centreon Engine. If not, see
- * <http://www.gnu.org/licenses/>.
+ * For more information : contact@centreon.com
  */
-
 #include "com/centreon/engine/hostescalation.hh"
 #include "com/centreon/engine/broker.hh"
 #include "com/centreon/engine/configuration/applier/state.hh"
@@ -25,6 +23,10 @@
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/shared.hh"
 #include "com/centreon/engine/string.hh"
+#ifdef LEGACY_CONF
+#else
+#include "common/engine_conf/state.pb.h"
+#endif
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
@@ -52,17 +54,15 @@ hostescalation::hostescalation(std::string const& host_name,
                                double notification_interval,
                                std::string const& escalation_period,
                                uint32_t escalate_on,
-                               Uuid const& uuid)
+                               const size_t key)
     : escalation{first_notification, last_notification, notification_interval,
-                 escalation_period,  escalate_on,       uuid},
+                 escalation_period,  escalate_on,       key},
       _hostname{host_name} {
   if (host_name.empty())
     throw engine_error() << "Could not create escalation "
                          << "on host '" << host_name << "'";
 }
 
-hostescalation::~hostescalation() {}
-
 std::string const& hostescalation::get_hostname() const {
   return _hostname;
 }
@@ -95,9 +95,8 @@ bool hostescalation::is_viable(int state, uint32_t notification_number) const {
     return retval;
 }
 
-void hostescalation::resolve(int& w, int& e) {
-  (void)w;
-  int errors{0};
+void hostescalation::resolve(uint32_t& w [[maybe_unused]], uint32_t& e) {
+  uint32_t errors = 0;
 
   // Find the host.
   host_map::const_iterator found(host::hosts.find(this->get_hostname()));
@@ -130,3 +129,67 @@ void hostescalation::resolve(int& w, int& e) {
     throw engine_error() << "Cannot resolve host escalation";
   }
 }
+
+#ifdef LEGACY_CONF
+/**
+ * @brief Checks that this hostescalation corresponds to the Configuration
+ * object obj. This function doesn't check contactgroups as it is usually used
+ * to modify them.
+ *
+ * @param obj A host escalation configuration object.
+ *
+ * @return A boolean that is True if they match.
+ */
+bool hostescalation::matches(const configuration::hostescalation& obj) const {
+  uint32_t escalate_on =
+      ((obj.escalation_options() & configuration::hostescalation::down)
+           ? notifier::down
+           : notifier::none) |
+      ((obj.escalation_options() & configuration::hostescalation::unreachable)
+           ? notifier::unreachable
+           : notifier::none) |
+      ((obj.escalation_options() & configuration::hostescalation::recovery)
+           ? notifier::up
+           : notifier::none);
+  if (_hostname != *obj.hosts().begin() ||
+      get_first_notification() != obj.first_notification() ||
+      get_last_notification() != obj.last_notification() ||
+      get_notification_interval() != obj.notification_interval() ||
+      get_escalation_period() != obj.escalation_period() ||
+      get_escalate_on() != escalate_on)
+    return false;
+
+  return true;
+}
+#else
+/**
+ * @brief Checks that this hostescalation corresponds to the Configuration
+ * object obj. This function doesn't check contactgroups as it is usually used
+ * to modify them.
+ *
+ * @param obj A host escalation configuration object.
+ *
+ * @return A boolean that is True if they match.
+ */
+bool hostescalation::matches(const configuration::Hostescalation& obj) const {
+  uint32_t escalate_on =
+      ((obj.escalation_options() & configuration::action_he_down)
+           ? notifier::down
+           : notifier::none) |
+      ((obj.escalation_options() & configuration::action_he_unreachable)
+           ? notifier::unreachable
+           : notifier::none) |
+      ((obj.escalation_options() & configuration::action_he_recovery)
+           ? notifier::up
+           : notifier::none);
+  if (_hostname != *obj.hosts().data().begin() ||
+      get_first_notification() != obj.first_notification() ||
+      get_last_notification() != obj.last_notification() ||
+      get_notification_interval() != obj.notification_interval() ||
+      get_escalation_period() != obj.escalation_period() ||
+      get_escalate_on() != escalate_on)
+    return false;
+
+  return true;
+}
+#endif
