@@ -1,5 +1,5 @@
 /**
-* Copyright 2022 Centreon
+* Copyright 2022-2024 Centreon
 *
 * This file is part of Centreon Engine.
 *
@@ -32,6 +32,7 @@ using namespace com::centreon::engine;
 using namespace com::centreon::engine::configuration::applier;
 using namespace com::centreon::engine::retention;
 
+#ifdef LEGACY_CONF
 /**
  *  Update service list.
  *
@@ -55,7 +56,33 @@ void applier::anomalydetection::apply(configuration::state const& config,
     }
   }
 }
+#else
+/**
+ *  Update service list.
+ *
+ *  @param[in] config                The global configuration.
+ *  @param[in] lst                   The service list to update.
+ *  @param[in] scheduling_info_is_ok True if the retention is not
+ *                                   outdated.
+ */
+void applier::anomalydetection::apply(const configuration::State & config,
+                                      const list_anomalydetection & lst,
+                                      bool scheduling_info_is_ok) {
+  for (auto& s : lst) {
+    try {
+      std::pair<uint64_t, uint64_t> id{
+          get_host_and_service_id(s->host_name(), s->service_description())};
+      engine::service& svc(find_service(id.first, id.second));
+      _update(config, *s, dynamic_cast<engine::anomalydetection&>(svc),
+              scheduling_info_is_ok);
+    } catch (...) {
+      // ignore exception for the retention.
+    }
+  }
+}
+#endif
 
+#ifdef LEGACY_CONF
 /**
  *  Update internal service base on service retention.
  *
@@ -76,3 +103,25 @@ void applier::anomalydetection::_update(
     obj.set_sensitivity(state.sensitivity());
   }
 }
+#else
+/**
+ *  Update internal service base on service retention.
+ *
+ *  @param[in]      config                The global configuration.
+ *  @param[in]      state                 The service retention state.
+ *  @param[in, out] obj                   The anomalydetection to update.
+ *  @param[in]      scheduling_info_is_ok True if the retention is
+ *                                        not outdated.
+ */
+void applier::anomalydetection::_update(
+    const configuration::State & config,
+    const retention::anomalydetection & state,
+    engine::anomalydetection& obj,
+    bool scheduling_info_is_ok) {
+  applier::service::update(config, state, static_cast<engine::service&>(obj),
+                           scheduling_info_is_ok);
+  if (state.sensitivity().is_set()) {
+    obj.set_sensitivity(state.sensitivity());
+  }
+}
+#endif
