@@ -17,7 +17,7 @@
  *
  */
 
-#include "com/centreon/engine/configuration/severity.hh"
+#include "common/engine_legacy_conf/severity.hh"
 #include <gtest/gtest.h>
 
 #include "helper.hh"
@@ -39,14 +39,16 @@ class ConfigSeverity : public ::testing::Test {
 // Then an exception is thrown.
 TEST_F(ConfigSeverity, NewSeverityWithNoKey) {
   configuration::severity sv({0, 0});
-  ASSERT_THROW(sv.check_validity(), std::exception);
+  configuration::error_cnt err;
+  ASSERT_THROW(sv.check_validity(err), std::exception);
 }
 
 // When I create a configuration::severity with a null level
 // Then an exception is thrown.
 TEST_F(ConfigSeverity, NewSeverityWithNoLevel) {
   configuration::severity sv({1, 0});
-  ASSERT_THROW(sv.check_validity(), std::exception);
+  configuration::error_cnt err;
+  ASSERT_THROW(sv.check_validity(err), std::exception);
 }
 
 // When I create a configuration::severity with an empty name
@@ -54,7 +56,8 @@ TEST_F(ConfigSeverity, NewSeverityWithNoLevel) {
 TEST_F(ConfigSeverity, NewSeverityWithNoName) {
   configuration::severity sv({1, 0});
   sv.parse("level", "2");
-  ASSERT_THROW(sv.check_validity(), std::exception);
+  configuration::error_cnt err;
+  ASSERT_THROW(sv.check_validity(err), std::exception);
 }
 
 // When I create a configuration::severity with a non empty name,
@@ -69,7 +72,8 @@ TEST_F(ConfigSeverity, NewSeverityWellFilled) {
   ASSERT_EQ(sv.level(), 2);
   ASSERT_EQ(sv.severity_name(), "foobar");
   ASSERT_EQ(sv.type(), configuration::severity::service);
-  ASSERT_NO_THROW(sv.check_validity());
+  configuration::error_cnt err;
+  ASSERT_NO_THROW(sv.check_validity(err));
 }
 
 // When I create a configuration::severity with an icon id.
@@ -81,5 +85,6 @@ TEST_F(ConfigSeverity, NewSeverityIconId) {
   sv.parse("severity_name", "foobar");
   sv.parse("type", "host");
   ASSERT_EQ(sv.icon_id(), 18);
-  ASSERT_NO_THROW(sv.check_validity());
+  configuration::error_cnt err;
+  ASSERT_NO_THROW(sv.check_validity(err));
 }
