@@ -24,16 +24,22 @@
 #include "../helper.hh"
 #include "../timeperiod/utils.hh"
 #include "com/centreon/engine/configuration/applier/host.hh"
-#include "com/centreon/engine/configuration/host.hh"
 #include "com/centreon/engine/exceptions/error.hh"
+#include "com/centreon/engine/host.hh"
 #include "com/centreon/engine/hostescalation.hh"
+#include "test_engine.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/host.hh"
+#else
+#include "common/engine_conf/host_helper.hh"
+#endif
 
 using namespace com::centreon;
 using namespace com::centreon::engine;
 using namespace com::centreon::engine::configuration;
 using namespace com::centreon::engine::configuration::applier;
 
-class HostRecovery : public ::testing::Test {
+class HostRecovery : public TestEngine {
  public:
   void SetUp() override {
     init_config_state();
@@ -41,10 +47,18 @@ class HostRecovery : public ::testing::Test {
     // other unload function... :-(
 
     configuration::applier::host hst_aply;
+#ifdef LEGACY_CONF
     configuration::host hst;
     hst.parse("host_name", "test_host");
     hst.parse("address", "127.0.0.1");
     hst.parse("_HOST_ID", "12");
+#else
+    configuration::Host hst;
+    configuration::host_helper hst_hlp(&hst);
+    hst.set_host_name("test_host");
+    hst.set_address("127.0.0.1");
+    hst.set_host_id(12);
+#endif
     hst_aply.add_object(hst);
     host_map const& hm{engine::host::hosts};
     _host = hm.begin()->second;
@@ -55,13 +69,15 @@ class HostRecovery : public ::testing::Test {
     _host->set_notify_on(static_cast<uint32_t>(-1));
     _current_time = 43200;
     set_time(_current_time);
-    _tperiod.reset(new engine::timeperiod("tperiod", "alias"));
+
+    _tperiod = new_timeperiod_with_timeranges("tperiod", "alias");
     for (size_t i = 0; i < _tperiod->days.size(); ++i)
       _tperiod->days[i].emplace_back(0, 86400);
 
+    /* 12345 is here to simulate a key. It won't allow any look up */
     std::unique_ptr<engine::hostescalation> host_escalation{
         new engine::hostescalation("host_name", 0, 1, 1.0, "tperiod", 7,
-                                   Uuid())};
+                                   12345)};
 
     _host->get_next_notification_id();
     _host->set_notification_period_ptr(_tperiod.get());
