@@ -1,22 +1,21 @@
 /**
- * Copyright 2024 Centreon
+ * Copyright 2011-2024 Centreon
  *
- * This file is part of Centreon Engine.
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
  *
- * Centreon Engine is free software: you can redistribute it and/or
- * modify it under the terms of the GNU General Public License version 2
- * as published by the Free Software Foundation.
+ * http://www.apache.org/licenses/LICENSE-2.0
  *
- * Centreon Engine is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * General Public License for more details.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
  *
- * You should have received a copy of the GNU General Public License
- * along with Centreon Engine. If not, see
- * <http://www.gnu.org/licenses/>.
  */
-
 #include <absl/container/btree_map.h>
 #include <absl/container/btree_set.h>
 #include <absl/container/flat_hash_map.h>
@@ -29,8 +28,10 @@
 #include "com/centreon/engine/configuration/applier/contact.hh"
 #include "com/centreon/engine/configuration/applier/host.hh"
 #include "com/centreon/engine/configuration/applier/service.hh"
-#include "com/centreon/engine/configuration/host.hh"
-#include "com/centreon/engine/configuration/service.hh"
+#ifdef LEGACY_CONF
+#include "common/engine_legacy_conf/host.hh"
+#include "common/engine_legacy_conf/service.hh"
+#endif
 
 #include "opentelemetry/proto/collector/metrics/v1/metrics_service.pb.h"
 #include "opentelemetry/proto/common/v1/common.pb.h"
@@ -49,7 +50,7 @@ class otl_converter_test : public TestEngine {};
 
 TEST_F(otl_converter_test, empty_metrics) {
   telegraf::nagios_check_result_builder conv("", spdlog::default_logger());
-  metrics_to_datapoints empty;
+  metric_to_datapoints empty;
   check_result res;
   ASSERT_FALSE(conv.build_result_from_metrics(empty, res));
 }
@@ -541,10 +542,11 @@ TEST_F(otl_converter_test, nagios_telegraf) {
   metric_request_ptr request =
       std::make_shared< ::opentelemetry::proto::collector::metrics::v1::
                             ExportMetricsServiceRequest>();
-  ::google::protobuf::util::JsonStringToMessage(telegraf_example,
-                                                request.get());
+  auto status = ::google::protobuf::util::JsonStringToMessage(telegraf_example,
+                                                              request.get());
 
-  metrics_to_datapoints received;
+  ASSERT_TRUE(status.ok()) << status.ToString();
+  metric_to_datapoints received;
   otl_data_point::extract_data_points(
       request, [&](const otl_data_point& data_pt) {
         received[data_pt.get_metric().name()].insert(data_pt);
@@ -573,7 +575,7 @@ TEST_F(otl_converter_test, nagios_telegraf_le_ge) {
 
   ::google::protobuf::util::JsonStringToMessage(example, request.get());
 
-  metrics_to_datapoints received;
+  metric_to_datapoints received;
   otl_data_point::extract_data_points(
       request, [&](const otl_data_point& data_pt) {
         received[data_pt.get_metric().name()].insert(data_pt);
@@ -600,7 +602,7 @@ TEST_F(otl_converter_test, nagios_telegraf_max) {
 
   ::google::protobuf::util::JsonStringToMessage(example, request.get());
 
-  metrics_to_datapoints received;
+  metric_to_datapoints received;
   otl_data_point::extract_data_points(
       request, [&](const otl_data_point& data_pt) {
         received[data_pt.get_metric().name()].insert(data_pt);
