@@ -1106,6 +1106,8 @@ CREATE TABLE `resources` (
   `last_check` bigint(20) unsigned DEFAULT NULL COMMENT 'the last check timestamp',
   `output` text DEFAULT NULL,
   `enabled` tinyint(1) NOT NULL DEFAULT 1 COMMENT '0=false, 1=true',
+  `flapping` tinyint(1) DEFAULT NULL,
+  `percent_state_change` double DEFAULT NULL,
   PRIMARY KEY (`resource_id`),
   UNIQUE KEY `resources_id_parent_id_type_uindex` (`id`,`parent_id`,`type`),
   KEY `resources_severities_severity_id_fk` (`severity_id`),
@@ -1526,3 +1528,16 @@ CREATE TABLE mod_bam_reporting_timeperiods (
 ) ENGINE=InnoDB CHARACTER SET utf8;
 
 SET FOREIGN_KEY_CHECKS=1;
+
+--
+-- Agent CEIP
+--
+DROP TABLE IF EXISTS agent_information;
+CREATE TABLE `centreon_storage`.`agent_information` (
+  `poller_id` BIGINT(20) NOT NULL,
+  `enabled` TINYINT(1) NOT NULL DEFAULT 1,
+  `infos` JSON NOT NULL,
+
+  PRIMARY KEY (`poller_id`),
+  KEY(enabled)
+) ENGINE=InnoDB CHARACTER SET utf8;
